---
name: "💉 Failing Test"
about: "Report failing tests or CI jobs."
title: "[Test] "
labels: "Type: Test"


---

# **💉 Failing Test**

## **Which jobs/test(s) are failing**
<!-- The CI jobs or tests that are failing -->

*

---

## **Reason for failure/description**
<!-- Try to describe why the test is failing or what we are missing to make it pass. -->

---

### **Media prove**
<!-- If applicable, add screenshots or videos to help explain your problem. -->

---

### **Additional context**
<!-- Add any other context or additional information about the problem here. -->

*

<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->
